@@ -25,9 +25,8 @@
 
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
-#include <libxfce4panel/xfce-hvbox.h>
 
 #include "time-out.h"
 #include "time-out-countdown.h"
@@ -78,7 +77,6 @@ struct _TimeOutPlugin
   GtkWidget         *hvbox;
   GtkWidget         *time_label;
   GtkWidget         *panel_icon;
-  GtkTooltips       *tooltips;
 };
 
 
@@ -149,7 +147,7 @@ static void           time_out_lock_countdown_finish              (TimeOutCountd
 
 
 /* Register the plugin */
-XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL (time_out_construct);
+XFCE_PANEL_PLUGIN_REGISTER (time_out_construct);
 
 
 
@@ -157,7 +155,6 @@ static TimeOutPlugin*
 time_out_new (XfcePanelPlugin *plugin)
 {
   TimeOutPlugin *time_out;
-  GtkWidget     *label;
   GtkOrientation orientation;
 
   /* Allocate memory for the plugin structure */
@@ -211,9 +208,6 @@ time_out_new (XfcePanelPlugin *plugin)
   gtk_box_pack_start (GTK_BOX (time_out->hvbox), time_out->time_label, TRUE, TRUE, 0);
   gtk_widget_show (time_out->time_label);
 
-  /* Create tooltips group */
-  time_out->tooltips = gtk_tooltips_new ();
-
   return time_out;
 }
 
@@ -341,6 +335,8 @@ time_out_enabled_toggled (GtkCheckMenuItem *menu_item,
     }
   else
     {
+      /* Update tooltips */
+      gtk_widget_set_tooltip_text(time_out->ebox, _("Paused"));
       /* Pause break countdown */
       time_out_countdown_pause (time_out->break_countdown);
     }
@@ -434,6 +430,36 @@ time_out_about (XfcePanelPlugin *plugin)
                          NULL);
 }
 
+GtkWidget *
+_xfce_create_framebox(const gchar *title, GtkWidget **frame_bin)
+{
+  GtkWidget *framebox;
+
+  g_return_val_if_fail(frame_bin, NULL);
+
+  framebox = gtk_frame_new(NULL);
+  gtk_frame_set_shadow_type(GTK_FRAME(framebox), GTK_SHADOW_NONE);
+  gtk_frame_set_label_align(GTK_FRAME(framebox), 0.0, 1.0);
+  gtk_widget_show(framebox);
+
+  if(title) {
+    gchar *tmp = g_strdup_printf("<b>%s</b>", title);
+    GtkWidget *label = gtk_label_new(tmp);
+    gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_widget_show(label);
+    gtk_frame_set_label_widget(GTK_FRAME(framebox), label);
+    g_free(tmp);
+  }
+
+  *frame_bin = gtk_alignment_new(0.0, 0.0, 1.0, 1.0);
+  gtk_alignment_set_padding(GTK_ALIGNMENT(*frame_bin), 5, 5, 21, 5);
+  gtk_widget_show(*frame_bin);
+  gtk_container_add(GTK_CONTAINER(framebox), *frame_bin);
+
+  return framebox;
+}
+
 static void
 time_out_configure (XfcePanelPlugin *plugin,
                     TimeOutPlugin   *time_out)
@@ -477,7 +503,7 @@ time_out_configure (XfcePanelPlugin *plugin,
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 
   /* Create time settings section */
-  framebox = xfce_create_framebox (_("Time settings"), &timebin);
+  framebox = _xfce_create_framebox (_("Time settings"), &timebin);
   gtk_container_set_border_width (GTK_CONTAINER (framebox), 6);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), framebox, TRUE, TRUE, 0);
   gtk_widget_show (framebox);
@@ -561,7 +587,7 @@ time_out_configure (XfcePanelPlugin *plugin,
   gtk_widget_show (spin);
 
   /* Create behaviour section */
-  framebox = xfce_create_framebox (_("Behaviour"), &behaviourbin);
+  framebox = _xfce_create_framebox (_("Behaviour"), &behaviourbin);
   gtk_container_set_border_width (GTK_CONTAINER (framebox), 6);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), framebox, TRUE, TRUE, 0);
   gtk_widget_show (framebox);
@@ -586,7 +612,7 @@ time_out_configure (XfcePanelPlugin *plugin,
   gtk_widget_show (checkbutton);
 
   /* Create appearance section */
-  framebox = xfce_create_framebox (_("Appearance"), &appearancebin);
+  framebox = _xfce_create_framebox (_("Appearance"), &appearancebin);
   gtk_container_set_border_width (GTK_CONTAINER (framebox), 6);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), framebox, TRUE, TRUE, 0);
   gtk_widget_show (framebox);
@@ -907,6 +933,7 @@ time_out_start_break_countdown (TimeOutPlugin *time_out,
                                 gint           seconds)
 {
   g_return_if_fail (time_out != NULL);
+  DBG("starting break countdown");
 
   if (G_UNLIKELY (!time_out->enabled))
     return;
@@ -924,6 +951,7 @@ static void
 time_out_start_lock_countdown (TimeOutPlugin *time_out)
 {
   g_return_if_fail (time_out != NULL);
+  DBG("starting lock countdown");
 
   /* Resume countdown if it was paused, otherwise start it */
   if (G_UNLIKELY (time_out_countdown_get_paused (time_out->lock_countdown)))
@@ -947,6 +975,7 @@ static void
 time_out_stop_break_countdown (TimeOutPlugin *time_out)
 {
   g_return_if_fail (time_out != NULL);
+  DBG("stopping break countdown");
 
   /* Stop the countdown */
   time_out_countdown_stop (time_out->break_countdown);
@@ -958,6 +987,7 @@ static void
 time_out_stop_lock_countdown (TimeOutPlugin *time_out)
 {
   g_return_if_fail (time_out != NULL);
+  DBG("stopping lock countdown");
 
   /* Stop the countdown */
   time_out_countdown_stop (time_out->lock_countdown);
@@ -1019,7 +1049,8 @@ time_out_break_countdown_update (TimeOutCountdown *countdown,
   gtk_label_set_text (GTK_LABEL (time_out->time_label), short_time_string->str);
 
   /* Update tooltips */
-  gtk_tooltips_set_tip (GTK_TOOLTIPS (time_out->tooltips), time_out->ebox, long_time_string->str, long_time_string->str);
+  if (time_out_countdown_get_running (countdown) && time_out->enabled)
+    gtk_widget_set_tooltip_text (time_out->ebox, long_time_string->str);
 
   /* Free time strings */
   g_string_free (short_time_string, TRUE);
@@ -1045,9 +1076,16 @@ time_out_lock_countdown_update (TimeOutCountdown *countdown,
                                 gint              seconds_remaining,
                                 TimeOutPlugin    *time_out)
 {
+  GString *long_time_string;
   g_return_if_fail (IS_TIME_OUT_COUNTDOWN (countdown));
   g_return_if_fail (time_out != NULL);
 
+
+  /* Update tooltips */
+  long_time_string = time_out_countdown_seconds_to_string (seconds_remaining, TRUE, TRUE, FALSE);
+  if (time_out_countdown_get_running (countdown))
+    gtk_widget_set_tooltip_text (time_out->ebox, long_time_string->str);
+
   /* Update lock screen */
   time_out_lock_screen_set_display_seconds (time_out->lock_screen, time_out->display_seconds);
   time_out_lock_screen_set_display_hours (time_out->lock_screen, time_out->display_hours);
